# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-10-14 07:06
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('articles', '0003_auto_20171005_0636'),
    ]

    operations = [
        migrations.CreateModel(
            name='ArticleTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(max_length=255, unique=True, verbose_name='Text')),
            ],
            options={
                'verbose_name': 'Article tag',
                'verbose_name_plural': 'Article tags',
            },
        ),
        migrations.AlterModelOptions(
            name='article',
            options={'ordering': ['-created'], 'verbose_name': 'Article', 'verbose_name_plural': 'Articles'},
        ),
        migrations.AlterField(
            model_name='article',
            name='created',
            field=models.DateTimeField(db_index=True, verbose_name='Created'),
        ),
        migrations.AlterField(
            model_name='article',
            name='description',
            field=models.CharField(max_length=255, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='article',
            name='is_comments_enabled',
            field=models.BooleanField(default=True, verbose_name='Is comments enabled'),
        ),
        migrations.AlterField(
            model_name='article',
            name='text',
            field=ckeditor_uploader.fields.RichTextUploadingField(max_length=50000, verbose_name='Text'),
        ),
        migrations.AlterField(
            model_name='article',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='article',
            name='type',
            field=models.CharField(choices=[(b'news', 'News')], default=None, max_length=255, verbose_name='Type'),
        ),
        migrations.AddField(
            model_name='article',
            name='tags',
            field=models.ManyToManyField(blank=True, related_name='tags', to='articles.ArticleTag', verbose_name='Tags'),
        ),
    ]




from django.shortcuts import get_object_or_404
from django.views.generic import ListView

from pure_pagination import PaginationMixin
from hitcount.views import HitCountDetailView

from articles.settings import ARTICLE_TYPE_CHOICES
from articles.models import Article


class ArticleListView(PaginationMixin, ListView):

    template_name = 'articles/list.html'
    paginate_by = 10

    def get_queryset(self):
        return Article.objects.filter(type=self.kwargs['type'])

    def get_context_data(self, **kwargs):
        cxt = super(ArticleListView, self).get_context_data(**kwargs)
        cxt['printable_article_type'] = (
            dict(ARTICLE_TYPE_CHOICES)[self.kwargs['type']])
        return cxt


class ArticleDetailView(HitCountDetailView):

    template_name = 'articles/info.html'
    count_hit = True

    def get_object(self, queryset=None):
        query = {
            'type': self.kwargs['type'],
            'pk': self.kwargs['id']
        }
        return get_object_or_404(Article, **query)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-03 15:14
from __future__ import unicode_literals

import ckeditor_uploader.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('articles', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='article',
            options={'ordering': ['-id'], 'verbose_name': '\u0421\u0442\u0430\u0442\u0442\u044f', 'verbose_name_plural': '\u0421\u0442\u0430\u0442\u0442\u0456'},
        ),
        migrations.AddField(
            model_name='article',
            name='created',
            field=models.DateTimeField(auto_now=True, db_index=True, verbose_name='Created'),
        ),
        migrations.AddField(
            model_name='article',
            name='is_comments_enabled',
            field=models.BooleanField(default=True, verbose_name='Is comments enabled'),
        ),
        migrations.AlterField(
            model_name='article',
            name='text',
            field=ckeditor_uploader.fields.RichTextUploadingField(max_length=10000, verbose_name='\u0422\u0435\u043a\u0441\u0442'),
        ),
    ]




from setuptools import setup, find_packages

from articles import __version__


with open('requirements.txt') as f:
    requires = f.read().splitlines()


url = 'https://github.com/pmaigutyak/mp-articles'


setup(
    name='django-mp-articles',
    version=__version__,
    description='Django articles apps',
    long_description=open('README.md').read(),
    author='Paul Maigutyak',
    author_email='pmaigutyak@gmail.com',
    url=url,
    download_url='%s/archive/%s.tar.gz' % (url, __version__),
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    install_requires=requires
)
